#ifndef NT2_INCLUDE_FUNCTIONS_ICEIL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ICEIL_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/iceil.hpp>

#endif
